ChangeLog
=========

.. _v0.6.0:

0.6.0 (2022-09-27)
------------------

*New Version:*

    - Upgraded version of Navconfig and AsyncDB.
    - Added support for Datamodels.
    - Security fixes

.. _v0.5.0:

0.5.24 (2022-08-02)
------------------

*New Version:*

    - Fix dependencies from asyncdb and NavConfig
    - Security fixes

0.5.0 (2022-03-02)
------------------

*New Version:*

    - Upgraded to Python +3.9
    - Fix dependencies with asyncdb and NavConfig
    - Changed the Telegram connector to aiogram


.. _v0.4.9:

0.4.9 (2022-03-01)
------------------

*New:*

    - Initial version

.. vim:set ft=rst:
